@@ -10,8 +10,6 @@ from typing import Iterable, List, Optional, Tuple
 
 from ibkr_report.definitions import (
     CURRENCY,
-    FIELD_COUNT,
-    OFFSET_DICT,
     USE_DEEMED_ACQUISITION_COST,
     AssetCategory,
     DataDiscriminator,
@@ -67,7 +65,7 @@ class Report:
         self.options = ReportOptions(
             report_currency=report_currency.upper(),
             deemed_acquisition_cost=use_deemed_acquisition_cost,
-            offset=0,
+            fields={},
         )
         self.rates = ExchangeRates()
         if file:
@@ -85,32 +83,47 @@ class Report:
     def is_stock_or_options_trade(self, items: Tuple[str, ...]) -> bool:
         """Checks whether the current row is part of a trade or not."""
         if (
-            len(items) == FIELD_COUNT + self.options.offset
-            and items[Field.TRADES] == FieldValue.TRADES
-            and items[Field.HEADER] == FieldValue.HEADER
-            and items[Field.DATA_DISCRIMINATOR]
+            all(
+                item in self.options.fields
+                for item in [
+                    Field.TRADES,
+                    Field.HEADER,
+                    Field.DATA_DISCRIMINATOR,
+                    Field.ASSET_CATEGORY,
+                ]
+            )
+            and items[self.options.fields[Field.TRADES]] == FieldValue.TRADES
+            and items[self.options.fields[Field.HEADER]] == FieldValue.HEADER
+            and items[self.options.fields[Field.DATA_DISCRIMINATOR]]
             in (DataDiscriminator.TRADE, DataDiscriminator.CLOSED_LOT)
-            and items[Field.ASSET_CATEGORY]
+            and items[self.options.fields[Field.ASSET_CATEGORY]]
             in (AssetCategory.STOCKS, AssetCategory.OPTIONS)
         ):
             return True
         return False
 
     def _handle_one_line(self, items: Tuple[str, ...]) -> None:
-        offset = OFFSET_DICT.get(items)
-        if offset is not None:
-            self.options.offset = offset
+        if len(items) > 2 and items[0] == Field.TRADES and items[1] == Field.HEADER:
+            self.options.fields = {}
             self._trade = None
+            for index, item in enumerate(items):
+                self.options.fields[item] = index
             return
         if self.is_stock_or_options_trade(items):
             self._handle_trade(items)
 
     def _handle_trade(self, items: Tuple[str, ...]) -> None:
         """Parses prices, gains, and losses from trades."""
-        if items[Field.DATA_DISCRIMINATOR] == DataDiscriminator.TRADE:
+        if (
+            items[self.options.fields[Field.DATA_DISCRIMINATOR]]
+            == DataDiscriminator.TRADE
+        ):
             self._trade = Trade(items, self.options, self.rates)
             self.prices += self._trade.total_selling_price
-        if items[Field.DATA_DISCRIMINATOR] == DataDiscriminator.CLOSED_LOT:
+        if (
+            items[self.options.fields[Field.DATA_DISCRIMINATOR]]
+            == DataDiscriminator.CLOSED_LOT
+        ):
             if not self._trade:
                 raise ValueError("Tried to close a lot without trades.")
             details = self._trade.details_from_closed_lot(items)
